@@ -148,32 +148,6 @@ int feh_load_image_char(Imlib_Image * im, char *filename)
 	return(i);
 }
 
-/*
- * XXX gib_imlib_save_image_with_error_return breaks with *.END and
- * similar because it tries to set the image format, which only works
- * with .end .
- * So we leave that part out.
- */
-void ungib_imlib_save_image_with_error_return(Imlib_Image im, char *file,
-	Imlib_Load_Error * error_return)
-{
-	char *tmp;
-	imlib_context_set_image(im);
-	tmp = strrchr(file, '.');
-	if (tmp) {
-		char *p, *pp;
-		p = estrdup(tmp + 1);
-		pp = p;
-		while(*pp) {
-			*pp = tolower(*pp);
-			pp++;
-		}
-		imlib_image_set_format(p);
-		free(p);
-	}
-	imlib_save_image_with_error_return(file, error_return);
-}
-
 void feh_imlib_print_load_error(char *file, winwidget w, Imlib_Load_Error err)
 {
 	if (err == IMLIB_LOAD_ERROR_OUT_OF_FILE_DESCRIPTORS)
@@ -276,7 +250,7 @@ int feh_load_image(Imlib_Image * im, feh_file * file)
 
 	if ((err) || (!im)) {
 		if (opt.verbose && !opt.quiet) {
-			fputs("\n", stdout);
+			fputs("\n", stderr);
 			reset_output = 1;
 		}
 		feh_imlib_print_load_error(file->filename, NULL, err);
@@ -996,7 +970,7 @@ void feh_display_status(char stat)
 	D(("filelist %p, filelist->next %p\n", filelist, filelist->next));
 
 	if (!stat) {
-		putc('\n', stdout);
+		putc('\n', stderr);
 		init_len = 0;
 		i = 0;
 		return;
@@ -1009,24 +983,24 @@ void feh_display_status(char stat)
 		if (reset_output) {
 			/* There's just been an error message. Unfortunate ;) */
 			for (j = 0; j < (((i % 50) + ((i % 50) / 10)) + 7); j++)
-				putc(' ', stdout);
+				putc(' ', stderr);
 		}
 
 		if (!(i % 50)) {
 			int len = gib_list_length(filelist);
 
-			fprintf(stdout, " %5d/%d (%d)\n[%3d%%] ",
+			fprintf(stderr, " %5d/%d (%d)\n[%3d%%] ",
 					i, init_len, len, ((int) ((float) i / init_len * 100)));
 
 		} else if ((!(i % 10)) && (!reset_output))
-			putc(' ', stdout);
+			putc(' ', stderr);
 
 		reset_output = 0;
 	} else
-		fputs("[  0%] ", stdout);
+		fputs("[  0%] ", stderr);
 
-	fprintf(stdout, "%c", stat);
-	fflush(stdout);
+	fprintf(stderr, "%c", stat);
+	fflush(stderr);
 	i++;
 	return;
 }
@@ -1055,7 +1029,7 @@ void feh_edit_inplace(winwidget w, int op)
 			imlib_image_flip_horizontal();
 		} else
 			gib_imlib_image_orientate(old, op);
-		ungib_imlib_save_image_with_error_return(old,
+		gib_imlib_save_image_with_error_return(old,
 			FEH_FILE(w->file->data)->filename, &err);
 		gib_imlib_free_image(old);
 		if (err)
